@@ -84,7 +84,7 @@
     (format
      nil
      "nsenter ~@[-S ~D ~]~@[-G ~D ~]-at ~D env -i ~{~A~^ ~} sh -c ~A"
-     uid gid pid (mapcar #'escape-sh-token env) (escape-sh-token cmd))))
+     uid gid pid (mapcar #'sh-escape env) (sh-escape cmd))))
 
 (defmethod establish-connection
     ((type (eql :nsenter)) remaining &key name pid uid gid)
@@ -114,7 +114,7 @@
 (defmethod initialize-instance :after
     ((connection lxc-unpriv-attach-connection) &key)
   (with-slots (owner owner-uid) connection
-    (when owner (setf owner-uid (user:passwd-entry 2 owner)))))
+    (when owner (setf owner-uid (user:passwd-field 2 owner)))))
 
 (defmethod connection-shell-wrap
     ((connection lxc-unpriv-attach-connection) cmd)
@@ -129,8 +129,9 @@
                   "--" "sh" "-c" ,cmd)))
       (if (and owner (not (string= owner (get-connattr :remote-user))))
           (with-connattrs (:remote-uid owner-uid)
-            (list* "runuser" "-u" owner "--" (apply #'systemd--user args)))
-          (apply #'systemd--user args)))))
+            (list* "runuser" "-u" owner "--"
+                   (systemd-user-instance-args args)))
+          (systemd-user-instance-args args)))))
 
 (defmethod establish-connection
     ((type (eql :lxc-unpriv-attach)) remaining &key owner name pid uid gid)
@@ -159,7 +160,7 @@ and
 
 will work but
 
-    ((:ssh :user \"root\") :sbcl (:setuid :to \"user\") (:lxc :name \"foo\"))
+    ((:ssh :user \"root\") :sbcl (:setuid :user \"user\") (:lxc :name \"foo\"))
 
 will not.  See \"Dumping and reinvoking Lisp\" in the \"Pitfalls and
 limitations\" section of the Consfigurator manual.
@@ -235,15 +236,15 @@ setgroups(2) is denied in the namespace."
     (linux-namespace-connection init-hooks-connection) ())
 
 #+linux
-(define-constant +namespace-types+ `(("user"   . ,+CLONE_NEWUSER+)
-                                     ("cgroup" . ,+CLONE_NEWCGROUP+)
-                                     ("ipc"    . ,+CLONE_NEWIPC+)
-                                     ("uts"    . ,+CLONE_NEWUTS+)
-                                     ("net"    . ,+CLONE_NEWNET+)
-                                     ("pid"    . ,+CLONE_NEWPID+)
-                                     ("mnt"    . ,+CLONE_NEWNS+)
-                                     ,@(and (boundp '+CLONE_NEWTIME+)
-                                            `(("time" . ,+CLONE_NEWTIME+))))
+(define-constant +namespace-types+ `(("user"   . ,CLONE_NEWUSER)
+                                     ("cgroup" . ,CLONE_NEWCGROUP)
+                                     ("ipc"    . ,CLONE_NEWIPC)
+                                     ("uts"    . ,CLONE_NEWUTS)
+                                     ("net"    . ,CLONE_NEWNET)
+                                     ("pid"    . ,CLONE_NEWPID)
+                                     ("mnt"    . ,CLONE_NEWNS)
+                                     ,@(and (boundp 'CLONE_NEWTIME)
+                                            `(("time" . ,CLONE_NEWTIME))))
   :test #'equal)
 
 (define-error-retval-cfun () "setns" :int (fd :int) (type :int))
@@ -310,14 +311,14 @@ setgroups(2) is denied in the namespace."
                      ;; indicates that the namespace we tried to join belongs
                      ;; to a parent userns, in which case if we were ever
                      ;; going to join it would have to have been on 1st pass.
-                     if (and fd setuserns (not (eql type +CLONE_NEWUSER+)))
+                     if (and fd setuserns (not (eql type CLONE_NEWUSER)))
                        do (handler-case (setns fd type) (nix:eperm ()))
                      else if fd do (setns fd type))
                ;; If we entered new PID or time namespaces then need to fork
                ;; so we're actually within them; for simplicity, always fork.
                (mapc-open-output-streams
-                #'force-output
-                *standard-output* *error-output* *debug-io* *terminal-io*)
+                #'force-output (list *debug-io* *terminal-io*
+                                     *standard-output* *error-output*))
                (let ((child (nix:fork)))
                  (when (plusp child)
                    (let ((status (nth-value 1 (nix:waitpid child))))
@@ -339,7 +340,7 @@ setgroups(2) is denied in the namespace."
                (val (subseq entry (1+ pos))))
           (unless
               (and uid
-                   (memstring= var '("HOME" "SHELL" "USER" "LOGNAME" "PATH")))
+                   (memstr= var '("HOME" "SHELL" "USER" "LOGNAME" "PATH")))
             (setf (getenv var) val))))
       (when gid
         (nix:setgid gid)
