@@ -17,6 +17,7 @@
                           #:subprocess-error
                           #:stripln
                           #:unix-namestring
+                          #:parse-unix-namestring
                           #:pathname-directory-pathname
                           #:pathname-parent-directory-pathname
                           #:resolve-symlinks
@@ -28,6 +29,7 @@
                           #:subpathp
                           #:relative-pathname-p
                           #:absolute-pathname-p
+                          #:directory-pathname-p
                           #:getenv
                           #:subdirectories
                           #:directory-files
@@ -57,6 +59,7 @@
            #:subprocess-error
            #:stripln
            #:unix-namestring
+           #:parse-unix-namestring
            #:pathname-directory-pathname
            #:pathname-parent-directory-pathname
            #:resolve-symlinks
@@ -68,6 +71,7 @@
            #:subpathp
            #:relative-pathname-p
            #:absolute-pathname-p
+           #:directory-pathname-p
            #:getenv
            #:subdirectories
            #:directory-files
@@ -88,16 +92,16 @@
            #:uid_t
            #:gid_t
 
-           #:+CLONE_NEWCGROUP+
-           #:+CLONE_NEWIPC+
-           #:+CLONE_NEWNET+
-           #:+CLONE_NEWNS+
-           #:+CLONE_NEWPID+
-           #:+CLONE_NEWTIME+
-           #:+CLONE_NEWUSER+
-           #:+CLONE_NEWUTS+
+           #:CLONE_NEWCGROUP
+           #:CLONE_NEWIPC
+           #:CLONE_NEWNET
+           #:CLONE_NEWNS
+           #:CLONE_NEWPID
+           #:CLONE_NEWTIME
+           #:CLONE_NEWUSER
+           #:CLONE_NEWUTS
 
-           #:+NS_GET_OWNER_UID+
+           #:NS_GET_OWNER_UID
 
            ;; util.lisp
            #:multiple-value-mapcan
@@ -105,28 +109,25 @@
            #:unlines
            #:words
            #:unwords
-           #:noop
-           #:symbol-named
-           #:memstring=
+           #:strip-prefix
+           #:memstr=
            #:define-simple-error
-           #:plist-to-cmd-args
-           #:systemd--user
+           #:plist-to-long-options
+           #:systemd-user-instance-args
 	   #:with-local-temporary-directory
            #:pathname-file
-           #:directory-contents
+           #:local-directory-contents
            #:ensure-trailing-slash
            #:drop-trailing-slash
-           #:quote-nonselfeval
-           #:define-print-object-for-structlike
+           #:define-simple-print-object
            #:chroot-pathname
            #:in-chroot-pathname
-           #:escape-sh-token
-           #:escape-sh-command
+           #:sh-escape
            #:defpackage-consfig
            #:lambda-ignoring-args
            #:parse-cidr
-           #:system
            #:random-alphanumeric
+           #:valid-hostname-p
 
            #:*consfigurator-debug-level*
            #:with-indented-inform
@@ -138,11 +139,10 @@
            #:version<=
            #:version>=
 
-           #:string->filename
-           #:filename->string
+           #:string-to-filename
+           #:filename-to-string
 
-           #:with-backtrace-and-exit-code
-           #:return-exit
+           #:exit-code-to-retval
            #:posix-login-environment
 
            #:define-error-retval-cfun
@@ -163,10 +163,10 @@
            #:connection-parent
            #:lisp-connection-p
            #:connection-run
-           #:connection-readfile
-           #:connection-readfile-and-remove
-           #:connection-writefile
-           #:connection-teardown
+           #:connection-read-file
+           #:connection-read-and-remove-file
+           #:connection-write-file
+           #:connection-tear-down
            #:connection-connattr
            #:propagate-connattr
 
@@ -177,36 +177,33 @@
            #:mktemp
            #:with-remote-current-directory
            #:run-failed
-           #:failed-cmd
-           #:failed-stdout
-           #:failed-stderr
-           #:failed-exit-code
+           #:run-failed-cmd
+           #:run-failed-stdout
+           #:run-failed-stderr
+           #:run-failed-exit
            #:runlines
-           #:test
+           #:remote-test
            #:remote-exists-p
            #:remote-file-stats
            #:remote-last-reboot
            #:remote-executable-find
-           #:mountpointp
+           #:remote-mount-point-p
            #:delete-remote-trees
            #:empty-remote-directory
-           #:readfile
-           #:writefile
+           #:read-remote-file
+           #:write-remote-file
            #:get-connattr
            #:with-connattrs
 
            ;; property.lisp
-           #:propattrs
-           #:propunapply
-           #:collapse-types
-           #:collapse-propapp-types
-           #:propapptype
-           #:propappargs
-           #:propappdesc
-           #:propappattrs
-           #:propappcheck
-           #:propappapply
-           #:propappunapply
+           #:combine-propapp-types
+           #:propapp-type
+           #:propapp-args
+           #:propapp-desc
+           #:propapp-attrs
+           #:check-propapp
+           #:apply-propapp
+           #:unapply-propapp
            #:ignoring-hostattrs
            #:defprop
            #:defpropspec
@@ -216,6 +213,7 @@
            #:get-hostattrs-car
            #:get-parent-hostattrs
            #:get-parent-hostattrs-car
+           #:push-hostattr
            #:push-hostattrs
            #:pushnew-hostattr
            #:pushnew-hostattrs
@@ -224,14 +222,11 @@
            #:require-data
            #:failed-change
            #:aborted-change
-           #:assert-euid-root
-           #:assert-connection-supports
-           #:maybe-writefile-string
-           #:call-with-os
+           #:assert-remote-euid-root
+           #:maybe-write-remote-file-string
            #:with-change-if-changes-file
            #:with-change-if-changes-files
            #:with-change-if-changes-file-content
-           #:with-change-if-changes-file-content-or-mode
 
            #:ptype
            #:plambda
@@ -240,7 +235,6 @@
 
            ;; propspec.lisp
            #:in-consfig
-           #:no-consfig
            #:propspec-systems
            #:propspec-props
            #:make-propspec
@@ -253,7 +247,6 @@
            #:seqprops
            #:eseqprops
            #:eseqprops-until
-           #:with-requirements
            #:silent-seqprops
            #:unapply
            #:unapplied
@@ -278,7 +271,6 @@
            #:preprocess-host
            #:ensure-host
            #:with-preserve-hostattrs
-           #:with-replace-hostattrs
            #:has-hostattrs
 
            ;; deployment.lisp
@@ -305,8 +297,8 @@
 
            ;; data.lisp
            #:data
-           #:iden1
-           #:iden2
+           #:data-iden1
+           #:data-iden2
            #:data-version
            #:data-mime
            #:string-data
@@ -314,7 +306,7 @@
            #:file-data
            #:data-file
 	   #:data-source-providing-p
-           #:maybe-writefile-data
+           #:maybe-write-remote-file-data
            #:missing-data-source
            #:data-pathname
 	   #:local-data-pathname
@@ -326,21 +318,23 @@
            #:try-register-data-source
            #:register-data-source
            #:reset-data-sources
-           #:skip-data-source
            #:get-data-stream
            #:with-data-stream
            #:get-data-string
            #:connection-upload
            #:connection-clear-data-cache
            #:upload-all-prerequisite-data
-           #:passphrase
-           #:make-passphrase
+           #:wrapped-passphrase
+           #:wrap-passphrase
+           #:unwrap-passphrase
            #:get-data-protected-string
+           #:*data-source-gnupghome*
+           #:with-reset-data-sources
+           #:missing-data
 
            ;; image.lisp
            #:eval-in-grandchild
            #:eval-in-reinvoked
-           #:dump-consfigurator-in-grandchild
            #:wrong-execution-context-for-image-dump
            #:image-dumped
            #:asdf-requirements-for-host-and-features
@@ -357,12 +351,12 @@
            (:use #:cffi)
            (:export #:acl_type_t
                     #:acl_entry_t
-                    #:+ACL-USER+
-                    #:+ACL-GROUP+
-                    #:+ACL-TYPE-ACCESS+
-                    #:+ACL-TYPE-DEFAULT+
-                    #:+ACL-NEXT-ENTRY+
-                    #:+ACL-FIRST-ENTRY+
+                    #:ACL_USER
+                    #:ACL_GROUP
+                    #:ACL_TYPE_ACCESS
+                    #:ACL_TYPE_DEFAULT
+                    #:ACL_NEXT_ENTRY
+                    #:ACL_FIRST_ENTRY
 
                     #:with-acl-free
                     #:acl-get-file
@@ -372,50 +366,50 @@
                     #:acl-get-qualifier
                     #:acl-set-qualifier
 
-                    #:+CAP-CHOWN+
-                    #:+CAP-DAC-OVERRIDE+
-                    #:+CAP-DAC-READ-SEARCH+
-                    #:+CAP-FOWNER+
-                    #:+CAP-FSETID+
-                    #:+CAP-KILL+
-                    #:+CAP-SETGID+
-                    #:+CAP-SETUID+
+                    #:CAP_CHOWN
+                    #:CAP_DAC_OVERRIDE
+                    #:CAP_DAC_READ_SEARCH
+                    #:CAP_FOWNER
+                    #:CAP_FSETID
+                    #:CAP_KILL
+                    #:CAP_SETGID
+                    #:CAP_SETUID
 
-                    #:+CAP-SETPCAP+
-                    #:+CAP-LINUX-IMMUTABLE+
-                    #:+CAP-NET-BIND-SERVICE+
-                    #:+CAP-NET-BROADCAST+
-                    #:+CAP-NET-ADMIN+
-                    #:+CAP-NET-RAW+
-                    #:+CAP-IPC-LOCK+
-                    #:+CAP-IPC-OWNER+
-                    #:+CAP-SYS-MODULE+
-                    #:+CAP-SYS-RAWIO+
-                    #:+CAP-SYS-CHROOT+
-                    #:+CAP-SYS-PTRACE+
-                    #:+CAP-SYS-PACCT+
-                    #:+CAP-SYS-ADMIN+
-                    #:+CAP-SYS-BOOT+
-                    #:+CAP-SYS-NICE+
-                    #:+CAP-SYS-RESOURCE+
-                    #:+CAP-SYS-TIME+
-                    #:+CAP-SYS-TTY-CONFIG+
-                    #:+CAP-MKNOD+
-                    #:+CAP-LEASE+
-                    #:+CAP-AUDIT-WRITE+
-                    #:+CAP-AUDIT-CONTROL+
-                    #:+CAP-SETFCAP+
-                    #:+CAP-MAC-OVERRIDE+
-                    #:+CAP-MAC-ADMIN+
-                    #:+CAP-SYSLOG+
-                    #:+CAP-WAKE-ALARM+
-                    #:+CAP-BLOCK-SUSPEND+
-                    #:+CAP-AUDIT-READ+
-                    #:+CAP-PERFMON+
-                    #:+CAP-BPF+
-                    #:+CAP-CHECKPOINT-RESTORE+
+                    #:CAP_SETPCAP
+                    #:CAP_LINUX_IMMUTABLE
+                    #:CAP_NET_BIND_SERVICE
+                    #:CAP_NET_BROADCAST
+                    #:CAP_NET_ADMIN
+                    #:CAP_NET_RAW
+                    #:CAP_IPC_LOCK
+                    #:CAP_IPC_OWNER
+                    #:CAP_SYS_MODULE
+                    #:CAP_SYS_RAWIO
+                    #:CAP_SYS_CHROOT
+                    #:CAP_SYS_PTRACE
+                    #:CAP_SYS_PACCT
+                    #:CAP_SYS_ADMIN
+                    #:CAP_SYS_BOOT
+                    #:CAP_SYS_NICE
+                    #:CAP_SYS_RESOURCE
+                    #:CAP_SYS_TIME
+                    #:CAP_SYS_TTY_CONFIG
+                    #:CAP_MKNOD
+                    #:CAP_LEASE
+                    #:CAP_AUDIT_WRITE
+                    #:CAP_AUDIT_CONTROL
+                    #:CAP_SETFCAP
+                    #:CAP_MAC_OVERRIDE
+                    #:CAP_MAC_ADMIN
+                    #:CAP_SYSLOG
+                    #:CAP_WAKE_ALARM
+                    #:CAP_BLOCK_SUSPEND
+                    #:CAP_AUDIT_READ
+                    #:CAP_PERFMON
+                    #:CAP_BPF
+                    #:CAP_CHECKPOINT_RESTORE
 
-                    #:capability-p))
+                    #:posix-capability-p))
 
   (package :consfigurator.util.linux-namespace
            (:use #:consfigurator.util.posix1e #:cffi)
@@ -430,7 +424,7 @@
 
   (package :consfigurator.property.file
            (:local-nicknames (#:re #:cl-ppcre))
-           (:export #:map-file-lines
+           (:export #:map-remote-file-lines
                     #:has-content
                     #:exists-with-content
                     #:contains-lines
@@ -459,14 +453,12 @@
 
   (package :consfigurator.property.etc-default
            (:local-nicknames (#:file  #:consfigurator.property.file))
-           (:shadow #:set)
-           (:export #:set))
+           (:export #:contains))
 
   (package :consfigurator.property.os
            (:shadow #:typecase #:etypecase)
            (:export #:unixlike
                     #:linux
-                    #:linux-architecture
                     #:debianlike
                     #:debian
                     #:debian-stable
@@ -475,15 +467,24 @@
                     #:debian-experimental
                     #:debian-suite
                     #:debian-architecture
+                    #:debian-architecture-string
+
                     #:typecase
                     #:host-typecase
                     #:etypecase
                     #:host-etypecase
+
+                    #:debian-suite-case
+                    #:host-debian-suite-case
+                    #:debian-suite-ecase
+                    #:host-debian-suite-ecase
+
                     #:required
                     #:supports-arch-p))
 
   (package :consfigurator.property.container
            (:export #:contained
+                    #:contained-p
                     #:when-contained))
 
   (package :consfigurator.property.periodic
@@ -498,8 +499,8 @@
                     #:unmounted-below
                     #:unmounted-below-and-removed
                     #:all-mounts
-                    #:*standard-linux-vfs*
-                    #:*linux-efivars-vfs*
+                    #:+linux-basic-vfs+
+                    #:+linux-efivars-vfs+
                     #:assert-devtmpfs-udev-/dev))
 
   (package :consfigurator.property.service
@@ -531,7 +532,7 @@
                     #:autoremoved
                     #:periodic-updates
                     #:unattended-upgrades
-                    #:mirror
+                    #:mirrors
                     #:uses-parent-mirrors
                     #:proxy
                     #:uses-parent-proxy
@@ -549,7 +550,7 @@
 
   (package :consfigurator.property.package
            (:local-nicknames (#:apt #:consfigurator.property.apt))
-           (:export #:*consfigurator-system-dependencies*
+           (:export #:+consfigurator-system-dependencies+
                     #:package-manager-not-found
                     #:installed))
 
@@ -567,7 +568,7 @@
 	            #:has-login-shell
                     #:has-enabled-password
                     #:has-locked-password
-	            #:passwd-entry))
+	            #:passwd-field))
 
   (package :consfigurator.property.chroot
            (:local-nicknames (#:service   #:consfigurator.property.service)
@@ -598,7 +599,7 @@
                     #:volume-label
                     #:volume-contents
                     #:volume-size
-                    #:volume-bootloader
+                    #:volume-bootloaders
                     #:subvolumes-of-type
                     #:all-subvolumes
                     #:copy-volume-and-contents
@@ -637,35 +638,36 @@
                     #:crypttab-keyfile
                     #:linux-swap
 
-                    #:with-these-open-volumes
+                    #:opened-volumes
+                    #:with-opened-volumes
 
                     #:has-volumes
-                    #:caches-cleaned
                     #:raw-image-built-for
                     #:debian-live-iso-built
                     #:debian-live-iso-built.
                     #:host-volumes-created
                     #:host-logical-volumes-exist
 
-                    #:parse-volume-size
                     #:volumes))
 
   (package :consfigurator.property.fstab
            (:use #:consfigurator.property.disk)
            (:local-nicknames (#:os    #:consfigurator.property.os)
-                             (#:file  #:consfigurator.property.file))
-           (:export #:volume->entry
-                    #:entries
-                    #:entries-for-volumes
-                    #:entries-for-opened-volumes))
+                             (#:file  #:consfigurator.property.file)
+                             (#:disk  #:consfigurator.property.disk))
+           (:export #:volume-to-entry
+                    #:has-entries
+                    #:has-entries-for-volumes
+                    #:has-entries-for-opened-volumes))
 
   (package :consfigurator.property.crypttab
            (:use #:consfigurator.property.disk)
            (:local-nicknames (#:re    #:cl-ppcre)
                              (#:os    #:consfigurator.property.os)
-                             (#:file  #:consfigurator.property.file))
-           (:export #:volume->entry
-                    #:entries-for-opened-volumes))
+                             (#:file  #:consfigurator.property.file)
+                             (#:disk  #:consfigurator.property.disk))
+           (:export #:volume-to-entry
+                    #:has-entries-for-opened-volumes))
 
   (package :consfigurator.property.gnupg
            (:local-nicknames (#:re        #:cl-ppcre))
@@ -691,7 +693,7 @@
            (:export #:installed
                     #:configured
                     #:no-passwords
-                    #:get-host-public-keys
+                    #:host-public-keys
                     #:has-host-public-key
                     #:has-host-key))
 
@@ -701,8 +703,8 @@
            (:export #:authorized-keys
                     #:has-user-key
                     #:known-host
-                    #:globally-known-host
-                    #:parent-is-globally-known-host))
+                    #:system-known-host
+                    #:parent-is-system-known-host))
 
   (package :consfigurator.property.locale
            (:local-nicknames (#:re        #:cl-ppcre)
@@ -715,10 +717,11 @@
 
   (package :consfigurator.property.reboot
            (:local-nicknames (#:container #:consfigurator.property.container))
-           (:export #:rebooted-at-end))
+           (:shadow #:at-end)
+           (:export #:at-end))
 
   (package :consfigurator.property.installer
-           (:use #:consfigurator.property.disk)
+           (:use #:consfigurator.property.disk #:cffi)
            (:local-nicknames (#:os        #:consfigurator.property.os)
                              (#:cmd       #:consfigurator.property.cmd)
                              (#:file      #:consfigurator.property.file)
@@ -726,10 +729,11 @@
                              (#:mount     #:consfigurator.property.mount)
                              (#:fstab     #:consfigurator.property.fstab)
                              (#:reboot    #:consfigurator.property.reboot)
-                             (#:crypttab  #:consfigurator.property.crypttab))
+                             (#:crypttab  #:consfigurator.property.crypttab)
+                             (#:disk      #:consfigurator.property.disk))
            (:export #:install-bootloader-propspec
                     #:install-bootloader-binaries-propspec
-                    #:chroot-installed-to-volumes
+                    #:chroot-installed-to-volumes-for
                     #:bootloader-binaries-installed
                     #:bootloaders-installed
                     #:cleanly-installed-once))
@@ -739,7 +743,8 @@
                  #:consfigurator.property.installer)
            (:local-nicknames (#:os        #:consfigurator.property.os)
                              (#:file      #:consfigurator.property.file)
-                             (#:apt       #:consfigurator.property.apt))
+                             (#:apt       #:consfigurator.property.apt)
+                             (#:container #:consfigurator.property.container))
            (:export #:grub
                     #:grub-installed))
 
@@ -747,9 +752,10 @@
            (:use #:consfigurator.property.disk
                  #:consfigurator.property.installer)
            (:local-nicknames (#:os        #:consfigurator.property.os)
-                             (#:apt       #:consfigurator.property.apt))
-           (:export #:u-boot-install-rockchip
-                    #:u-boot-installed-rockchip))
+                             (#:apt       #:consfigurator.property.apt)
+                             (#:container #:consfigurator.property.container))
+           (:export #:install-rockchip
+                    #:installed-rockchip))
 
   (package :consfigurator.property.hostname
            (:local-nicknames (#:cmd       #:consfigurator.property.cmd)
@@ -780,7 +786,7 @@
            (:export #:installed
                     #:default-network-started
                     #:default-network-autostarted
-                    #:defined
+                    #:defined-for
                     #:started
                     #:destroyed
                     #:when-started
@@ -796,7 +802,7 @@
                              (#:apt       #:consfigurator.property.apt))
            (:export #:installed
                     #:has-limits
-                    #:group-cache))
+                    #:cache-for-group))
 
   (package :consfigurator.property.schroot
            (:local-nicknames (#:os        #:consfigurator.property.os)
@@ -843,7 +849,7 @@
            (:export #:system-job
                     #:nice-system-job
                     #:runs-consfigurator
-                    #:user-crontab))
+                    #:user-crontab-installed))
 
   (package :consfigurator.property.lets-encrypt
            (:local-nicknames (#:apt       #:consfigurator.property.apt)
@@ -893,18 +899,19 @@
                              (#:os          #:consfigurator.property.os)
                              (#:service     #:consfigurator.property.service))
            (:export #:installed
-                    #:service
-                    #:policy
-                    #:zone
+                    #:knows-service
+                    #:has-policy
+                    #:has-zone-xml
                     #:has-zone
-                    #:zone-target
+                    #:zone-has-target
                     #:default-route-zoned-once
                     #:zone-has-interface
+                    #:zone-has-source
                     #:zone-has-service
-                    #:zone-masquerade
-                    #:zone-rich-rule
-                    #:direct-rule
-                    #:default-zone))
+                    #:zone-has-masquerade
+                    #:zone-has-rich-rule
+                    #:has-direct-rule
+                    #:has-default-zone))
 
   (package :consfigurator.property.timezone
            (:local-nicknames (#:file         #:consfigurator.property.file)
@@ -932,7 +939,7 @@
                     #:user-container-started
                     #:when-user-container-running
                     #:user-containers-autostart
-                    #:usernet-usable-by
+                    #:usernet-veth-usable-by
                     #:user-container-for
                     #:user-container-for.
                     #:user-container
@@ -948,9 +955,9 @@
                     #:superuser-is
                     #:has-role
                     #:has-database
-                    #:has-owner
+                    #:database-has-owner
                     #:has-group
-                    #:can-login))
+                    #:user-can-login))
 
   (package :consfigurator.connection.local
            (:export #:local-connection))
@@ -967,7 +974,7 @@
   (package :consfigurator.connection.rehome
            (:use #:consfigurator.connection.fork)
            (:export #:rehome-connection
-                    #:datadir))
+                    #:rehome-datadir))
 
   (package :consfigurator.connection.as
            (:use #:consfigurator.connection.fork #:cffi))
@@ -1003,9 +1010,13 @@
            (:local-nicknames (#:user #:consfigurator.property.user)
                              (#:lxc  #:consfigurator.property.lxc)))
 
+  (package :consfigurator.data.util
+           (:export #:literal-data-pathname #:gpg-file-as-string #:gpg))
+
   (package :consfigurator.data.asdf)
 
   (package :consfigurator.data.pgp
+           (:use  #:consfigurator.data.util)
            (:export #:list-data #:get-data #:set-data #:set-data-from-file))
 
   (package :consfigurator.data.git-snapshot)
@@ -1017,4 +1028,8 @@
 
   (package :consfigurator.data.local-file)
 
-  (package :consfigurator.data.files-tree))
+  (package :consfigurator.data.pass
+           (:use  #:consfigurator.data.util))
+
+  (package :consfigurator.data.files-tree
+           (:use  #:consfigurator.data.util)))
