@@ -50,20 +50,20 @@ containing this one.
 
 If a larger size is required to accommodate the VOLUME-CONTENTS of the volume
 plus any metadata (e.g. partition tables), this value will be ignored.")
-   (volume-bootloader
-    :type list :initarg :boots-with :accessor volume-bootloader
+   (volume-bootloaders
+    :type list :initarg :boots-with :accessor volume-bootloaders
     :documentation
-    "List specifying a bootloader to be installed to this volume.  The first
-element is a symbol identifying the type of bootloader, and the remaining
-elements are a plist of keyword arguments to be passed to the implementation
-of INSTALLER:INSTALL-BOOTLOADER for that bootloader type.
+    "List or list of lists specifying bootloaders to be installed to this volume.
+The first element of each list is a symbol identifying the type of bootloader,
+and the remaining elements are a plist of keyword arguments to be passed to
+the implementation of INSTALLER:INSTALL-BOOTLOADER for that bootloader type.
 
 Typically only the top level PHYSICAL-DISK of a host's volumes will have this
 slot bound."))
   (:documentation
    "Something which contains filesystems and/or other volumes."))
 
-(define-print-object-for-structlike volume)
+(define-simple-print-object volume)
 
 (defgeneric copy-volume-and-contents
     (volume &rest initialisations &key &allow-other-keys)
@@ -283,7 +283,7 @@ directly writing out with dd(1)."))
 (defmethod create-volume ((volume raw-disk-image) (file null))
   "Ensure that a raw disk image exists.  Will overwrite only regular files."
   (let ((file (image-file volume)))
-    (when (test "-L" file "-o" "-e" file "-a" "!" "-f" file)
+    (when (remote-test "-L" file "-o" "-e" file "-a" "!" "-f" file)
       (failed-change "~A already exists and is not a regular file." file))
     ;; Here, following Propellor, we want to ensure that the disk image size
     ;; is a multiple of 4096 bytes, so that the size is aligned to the common
@@ -451,7 +451,7 @@ We do not specify what logical volumes it contains."))
         (and (slot-boundp volume 'data-alignment)
              `("--dataalignment" ,(data-alignment volume)))
         file)
-  (if (member (lvm-volume-group volume) (all-vgs) :test #'string=)
+  (if (memstr= (lvm-volume-group volume) (all-lvm-volume-groups))
       (mrun :inform "vgextend" (lvm-volume-group volume) file)
       (mrun :inform "vgcreate" "--systemid" ""
             (and (slot-boundp volume 'physical-extent-size)
@@ -460,7 +460,7 @@ We do not specify what logical volumes it contains."))
                  `("--alloc" ,(alloc volume)))
             (lvm-volume-group volume) file)))
 
-(defun all-vgs ()
+(defun all-lvm-volume-groups ()
   (mapcar (curry #'string-trim " ")
           (runlines "vgs" "--no-headings" "-ovg_name")))
 
@@ -499,7 +499,7 @@ We do not specify what logical volumes it contains."))
 (defmethod create-volume ((volume lvm-logical-volume) (file null))
   (with-slots (volume-label lvm-volume-group) volume
     ;; Check that the VG exists.
-    (unless (member lvm-volume-group (all-vgs) :test #'string=)
+    (unless (memstr= lvm-volume-group (all-lvm-volume-groups))
       (failed-change "Looks like no PVs for VG ~A?" lvm-volume-group))
     ;; Create the LV.
     (mrun :inform "lvcreate" "-Wn"
@@ -513,7 +513,7 @@ We do not specify what logical volumes it contains."))
   (:desc "Host LVM logical volumes all exist")
   (:hostattrs (os:required 'os:linux))
   (:apply
-   (assert-euid-root)
+   (assert-remote-euid-root)
    (let* ((existing-lvs
             (loop for (lv vg) in (mapcar #'words (cdr (runlines "lvs")))
                   collect (cons lv vg)))
@@ -532,8 +532,9 @@ We do not specify what logical volumes it contains."))
                               when (slot-boundp volume 'mount-point)
                                 collect volume))))
      (if to-create
-         (prog2 (ignoring-hostattrs
-                 (consfigurator.property.fstab:entries-for-volumes to-create))
+         (prog2
+             (ignoring-hostattrs
+              (consfigurator.property.fstab:has-entries-for-volumes to-create))
              (create-volumes-and-contents to-create)
            (dolist (volume to-create)
              (open-volume volume nil))
@@ -666,7 +667,7 @@ order in which they should be closed.  MOUNT-BELOW specifies a pathname to
 prefix to mount points when opening FILESYSTEM volumes.
 
 Calling this function can be useful for testing at the REPL, but code should
-normally use WITH-OPEN-VOLUMES or WITH-THESE-OPEN-VOLUMES.
+normally use WITH-OPEN-VOLUMES or WITH-OPENED-VOLUMES.
 
 If an error is signalled while the attempt to open volumes is in progress, a
 single attempt will be made to close all volumes opened up to that point."
@@ -730,7 +731,7 @@ populate /etc/fstab and /etc/crypttab.  Do not modify this list."
          (mrun "sync")
          (mapc #'close-volume ,opened-volumes)))))
 
-(defmacro with-these-open-volumes
+(defmacro with-opened-volumes
     ((volumes &key (mount-below nil mount-below-supplied-p)) &body propapps)
   "Macro property combinator.  Where each of VOLUMES is a VOLUME which may be
 opened by calling OPEN-VOLUME with NIL as the second argument, recursively
@@ -738,30 +739,30 @@ open each of VOLUMES and any contents thereof, apply PROPAPPS, and close all
 volumes that were opened.
 
 MOUNT-BELOW specifies a pathname to prefix to mount points when opening
-FILESYSTEM volumes.  During the application of PROPAPPS, all :OPENED-VOLUMES
-connattrs are replaced with a list of the volumes that were opened; this list
-must not be modified."
-  `(with-these-open-volumes*
+FILESYSTEM volumes.  During the application of PROPAPPS, all
+'DISK:OPENED-VOLUMES connattrs are replaced with a list of the volumes that
+were opened; this list must not be modified."
+  `(with-opened-volumes*
      ',volumes
      ,(if (cdr propapps) `(eseqprops ,@propapps) (car propapps))
      ,@(and mount-below-supplied-p `(:mount-below ,mount-below))))
 
-(define-function-property-combinator with-these-open-volumes*
+(define-function-property-combinator with-opened-volumes*
     (volumes propapp &key (mount-below nil mount-below-supplied-p))
   (:retprop
-   :type (propapptype propapp)
+   :type (propapp-type propapp)
    :hostattrs (lambda-ignoring-args
                 (require-volumes-data volumes)
-                (propappattrs propapp))
+                (propapp-attrs propapp))
    :apply
    (lambda-ignoring-args
-     (with-connattrs (:opened-volumes
+     (with-connattrs ('opened-volumes
                       (apply #'open-volumes-and-contents
                              `(,volumes ,@(and mount-below-supplied-p
                                                `(:mount-below ,mount-below)))))
-       (unwind-protect (propappapply propapp)
+       (unwind-protect (apply-propapp propapp)
          (mrun "sync")
-         (mapc #'close-volume (get-connattr :opened-volumes)))))
+         (mapc #'close-volume (get-connattr 'opened-volumes)))))
    :args (cdr propapp)))
 
 (defun create-volumes-and-contents (volumes &optional files)
@@ -817,8 +818,9 @@ the LVM physical volumes corresponding to those volume groups."
   (:desc "Has specified volumes.")
   (:hostattrs
    (os:required 'os:linux)
-   (apply #'push-hostattrs :volumes volumes)))
+   (push-hostattrs :volumes volumes)))
 
+;; TODO This should probably be in another package, and exported from there.
 (defproplist caches-cleaned :posix ()
   "Clean all caches we know how to clean in preparation for image creation."
   (:desc "Caches cleaned")
@@ -939,15 +941,15 @@ filesystems will be incrementally updated when other properties change."
                              (caches-cleaned)))
                  (%raw-image-created
                   ,volumes :chroot ,chroot :rebuild ,rebuild))
-       (consfigurator.property.installer:chroot-installed-to-volumes
+       (consfigurator.property.installer:chroot-installed-to-volumes-for
         ,host ,chroot ,volumes))))
 
 (defprop %squashfsed :posix (chroot image &optional (compression "xz"))
   (:apply
    (file:does-not-exist image)
    (with-remote-temporary-file (excludes)
-     (writefile excludes
-                (format nil "~@{~&~A~}" "/boot" "/proc" "/dev" "/sys" "/run"))
+     (write-remote-file
+      excludes (format nil "~@{~&~A~}" "/boot" "/proc" "/dev" "/sys" "/run"))
      (run :inform "nice" "mksquashfs" chroot image
           "-no-progress" "-comp" compression "-ef" excludes))))
 
@@ -981,7 +983,7 @@ Currently only BIOS boot is implemented."
                      "live-boot" "task-laptop" "libnss-myhostname"
                      "syslinux-common" "isolinux")
                     (caches-cleaned))))))
-         (host-arch (os:linux-architecture (get-hostattrs-car :os host))))
+         (host-arch (os:debian-architecture (get-hostattrs-car :os host))))
       options
     (unless (member host-arch '(:amd64))
       (inapplicable-property
