@@ -18,16 +18,16 @@
 (in-package :consfigurator.property.reboot)
 (named-readtables:in-readtable :consfigurator)
 
-(defprop %rebooted-at-end :posix ()
-  (:apply (at-end
+(defprop %at-end :posix ()
+  (:apply (consfigurator:at-end
            (lambda (result)
              (declare (ignore result))
              (mrun "shutdown" "-r" "+1")
              (inform t "*** SYSTEM REBOOT SCHEDULED, one minute delay ***")))))
 
-(defproplist rebooted-at-end :posix ()
+(defproplist at-end :posix ()
   "Schedule a reboot for the end of the current (sub)deployment.
 The reboot is scheduled with a one minute delay to allow remote Lisp images to
 return correct exit statuses to the root Lisp, for the root Lisp to have time
 to download their output, etc."
-  (container:when-contained (:reboot) (%rebooted-at-end)))
+  (container:when-contained (:reboot) (%at-end)))
