@@ -26,19 +26,19 @@ Note that this uses getent(1) and so is not strictly POSIX-compatible."
   (:check
    (user-exists username))
   (:apply
-   (assert-euid-root)
+   (assert-remote-euid-root)
    (mrun "useradd" "-m" username)))
 
 (defprop %has-uid-gid :posix (username uid gid)
   (:check
-   (and (= uid (parse-integer (passwd-entry 2 username)))
-        (= gid (parse-integer (passwd-entry 3 username)))
+   (and (= uid (parse-integer (passwd-field 2 username)))
+        (= gid (parse-integer (passwd-field 3 username)))
         (= gid (parse-integer (group-entry 2 username)))))
   (:apply
    (let* ((gid-str (write-to-string gid))
           (uid-str (write-to-string uid))
           (uid+gid (format nil "~d:~d" uid gid))
-          (home (passwd-entry 5 username)))
+          (home (passwd-field 5 username)))
      (mrun "groupmod" "--gid" gid-str username)
      (mrun "usermod" "--uid" uid-str "--gid" gid-str username)
      (mrun "chown" "-R" uid+gid home))))
@@ -61,7 +61,7 @@ that group, and ~USERNAME and its contents are owned by UID:GID."
    (subsetp groups (cddr (split-string (stripln (run "groups" username))))
             :test #'string=))
   (:apply
-   (assert-euid-root)
+   (assert-remote-euid-root)
    (mrun "usermod" "-a" "-G" groups* username)))
 
 (defparameter *desktop-groups*
@@ -77,10 +77,10 @@ the installation of other software."
   (:hostattrs (os:required 'os:debianlike))
   (:apply
    (let ((existing-groups
-           (loop for line in (lines (readfile "/etc/group"))
+           (loop for line in (lines (read-remote-file "/etc/group"))
                  collect (car (split-string line :separator ":")))))
      (apply #'has-groups username (loop for group in *desktop-groups*
-                                        when (memstring= group existing-groups)
+                                        when (memstr= group existing-groups)
                                           collect group)))))
 
 (defprop has-login-shell :posix (username shell)
@@ -88,7 +88,7 @@ the installation of other software."
 Note that this uses getent(1) and so is not strictly POSIX-compatible."
   (:desc #?"${username} has login shell ${shell}")
   (:check
-   (string= (passwd-entry 6 username) shell))
+   (string= (passwd-field 6 username) shell))
   (:apply
    (file:contains-lines "/etc/shells" shell)
    (mrun "chsh" "--shell" shell username)))
@@ -113,10 +113,10 @@ and then this property will do nothing."
   (:desc #?"${username} has a locked password")
   (:hostattrs (os:required 'os:debianlike))
   (:check
-   (assert-euid-root)
+   (assert-remote-euid-root)
    (string= "L" (cadr (split-string (run "passwd" "-S" username)))))
   (:apply
-   (assert-euid-root)
+   (assert-remote-euid-root)
    (mrun "passwd" "--lock" username)))
 
 (defun %getent-entry (n name-or-id &optional (database "passwd"))
@@ -127,7 +127,7 @@ and then this property will do nothing."
     (nth n (split-string (stripln (mrun "getent" database u))
                          :separator ":"))))
 
-(defun passwd-entry (n username-or-uid)
+(defun passwd-field (n username-or-uid)
   "Get the nth entry in the getent(1) output for USERNAME-OR-UID.
 Note that getent(1) is not specified in POSIX so use of this function makes
 properties not strictly POSIX-compatible."
