@@ -1,6 +1,6 @@
 ;;; Consfigurator -- Lisp declarative configuration management system
 
-;;; Copyright (C) 2020-2021  Sean Whitton <spwhitton@spwhitton.name>
+;;; Copyright (C) 2020-2022  Sean Whitton <spwhitton@spwhitton.name>
 
 ;;; This file is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -35,11 +35,6 @@
              (loop for result in new-results and i upfrom 0
                    do (nconcf (aref results i) result)))))
 
-(defun noop (&rest args)
-  "Accept any arguments and do nothing."
-  (declare (ignore args))
-  (values))
-
 (defun lines (text &optional trimfun (trimchars '(#\Space #\Tab)))
   (with-input-from-string (stream text)
     (let (bolp buffer)
@@ -77,11 +72,12 @@
 (defun unwords (words)
   (format nil "~{~A~^ ~}" words))
 
-(defmacro symbol-named (name symbol)
-  `(and (symbolp ,symbol)
-        (string= (symbol-name ',name) (symbol-name ,symbol))))
+(defun strip-prefix (prefix string)
+  "If STRING is prefixed by PREFIX, return the rest of STRING,
+otherwise return NIL."
+  (nth-value 1 (starts-with-subseq prefix string :return-suffix t)))
 
-(defun memstring= (string list)
+(defun memstr= (string list)
   (member string list :test #'string=))
 
 (defun assert-ordinary-ll-member (arg)
@@ -169,11 +165,11 @@ supported."
         do (pop forms)
         finally (return forms)))
 
-(defun plist-to-cmd-args (plist &aux args)
+(defun plist-to-long-options (plist &aux args)
   (doplist (k v plist args)
            (push (strcat "--" (string-downcase (symbol-name k)) "=" v) args)))
 
-(defun systemd--user (&rest args)
+(defun systemd-user-instance-args (args)
   "Where ARGS are args to RUN or MRUN for an invocation of a systemd command
 which can take \"--user\", insert the \"--user\" parameter, and modify or
 insert an :ENV parameter so that the call is more likely to succeed."
@@ -218,7 +214,7 @@ directory, one solution is to convert your property to a :LISP property."
             (enough-pathname pathname (pathname-directory-pathname pathname))
             pathname))))
 
-(defun directory-contents (pathname)
+(defun local-directory-contents (pathname)
   "Return the immediate contents of PATHNAME, a directory, without resolving
 symlinks.  Not suitable for use by :POSIX properties."
   ;; On SBCL on Debian UIOP:*WILD-FILE-FOR-DIRECTORY* is #P"*.*".
@@ -236,25 +232,24 @@ symlinks.  Not suitable for use by :POSIX properties."
       (subseq namestring 0 (1- (length namestring)))
       namestring))
 
-(defun reinit-structlike (class &rest slots)
-  (loop with object = (allocate-instance (find-class class))
-        for (slot-name slot-value) on slots by #'cddr
-        do (setf (slot-value object slot-name) slot-value)
-        finally (return (reinitialize-instance object))))
+(defun reinit-from-simple-print (class &rest slots)
+  (aprog1 (allocate-instance (find-class class))
+    (loop for (slot-name slot-value) on slots by #'cddr
+          do (setf (slot-value it slot-name) slot-value))))
 
 (defmacro quote-nonselfeval (x)
   (once-only (x)
     `(if (member (type-of ,x) '(cons symbol))
          `',,x ,x)))
 
-(defmacro define-print-object-for-structlike (class)
-  "Define an implementation of PRINT-OBJECT for objects which are simple
-one-dimensional collections of values."
+(defmacro define-simple-print-object (class)
+  "Define an implementation of PRINT-OBJECT suitable for classes representing
+simple collections of readably-printable values."
   `(defmethod print-object ((object ,class) stream)
      (if (and *print-readably* *read-eval*)
          (format
           stream "#.~S"
-          `(reinit-structlike
+          `(reinit-from-simple-print
             ',(type-of object)
             ;; Call CLASS-OF so that subclasses of CLASS are handled too.
             ,@(loop for slot in (closer-mop:class-slots (class-of object))
@@ -274,13 +269,11 @@ one-dimensional collections of values."
   (ensure-pathname (enough-pathname pathname chroot)
                    :ensure-absolute t :defaults #P"/"))
 
-(defun escape-sh-token (token &optional s)
-  "Like UIOP:ESCAPE-SH-TOKEN, but also escape the empty string."
-  (if (string= token "") (format s "\"\"") (uiop:escape-sh-token token s)))
-
-(defun escape-sh-command (command &optional s)
-  "Like UIOP:ESCAPE-SH-COMMAND, but also escape the empty string."
-  (uiop:escape-command command s 'escape-sh-token))
+(defun sh-escape (token-or-cmd &optional s)
+  (cond ((listp token-or-cmd) (uiop:escape-command token-or-cmd s 'sh-escape))
+        ((pathnamep token-or-cmd) (sh-escape (unix-namestring token-or-cmd) s))
+        ((string= token-or-cmd "") (format s "\"\""))
+        (t (uiop:escape-sh-token token-or-cmd s))))
 
 (defun parse-username-from-id (output)
   "Where OUTPUT is the output of the id(1) command, extract the username."
@@ -359,18 +352,6 @@ expansion as a starting point for your own DEFPACKAGE form for your consfig."
                                        else do (princ #\: s)
                                                (loop-finish)))))))))
 
-(defun system (&rest args)
-  "Simple wrapper around system(3)."
-  (foreign-funcall
-   "system" :string (if (cdr args)
-                        (escape-sh-command
-                         (loop for arg in args
-                               if (pathnamep arg)
-                                 collect (unix-namestring arg)
-                               else collect arg))
-                        (car args))
-   :int))
-
 (eval-when (:compile-toplevel :load-toplevel :execute)
   (define-constant +alphanum+
     "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
@@ -423,6 +404,17 @@ expansion as a starting point for your own DEFPACKAGE form for your consfig."
   (with-standard-io-syntax
     (write object :stream fifo) (terpri fifo) (finish-output fifo)))
 
+(defun valid-hostname-p (string)
+  "Test whether STRING looks like a valid hostname, as defined by RFCs 952 and
+1123."
+  (and
+   (<= (length string) 253)
+   (let ((parts (split-string string :separator ".")))
+     (every (lambda (part)
+              (and (<= (length part) 63)
+                   (re:scan "^[a-zA-Z0-9][a-zA-Z0-9-]*$" part)))
+            parts))))
+
 
 ;;;; Progress & debug printing
 
@@ -522,7 +514,7 @@ previous output."
 ;; This implementation also assumes that the Lisp doing the decoding has the
 ;; same charset as the Lisp doing the encoding.
 
-(defun string->filename (s)
+(defun string-to-filename (s)
   (apply #'concatenate 'string
          (loop for c
                  across (etypecase s (string s) (number (write-to-string s)))
@@ -533,7 +525,7 @@ previous output."
                else
                  collect (format nil "_~X_" (char-code c)))))
 
-(defun filename->string (s)
+(defun filename-to-string (s)
   (loop with decoding
         with buffer
         with result
@@ -573,8 +565,8 @@ previous output."
     `(progn
        #-(or sbcl) (error "Don't know how to safely fork(2) in this Lisp.")
        (mapc-open-output-streams
-        #'force-output
-        *standard-output* *error-output* *debug-io* *terminal-io*)
+        #'force-output (list *debug-io* *terminal-io*
+                             *standard-output* *error-output*))
        (let ((,retval (fork)))
          (if (zerop ,retval)
              ;; We leave it to the caller to appropriately call CLOSE or
@@ -624,7 +616,7 @@ interactive debugger."))
                         (,failures               22)
                         (t                       23))))))
 
-(defmacro return-exit (exit &key on-failure)
+(defmacro exit-code-to-retval (exit &key on-failure)
   `(values
     nil
     (case ,exit
@@ -724,7 +716,7 @@ Does not currently establish a PAM session."
     (two-way-stream (two-way-stream-input-stream stream))
     (stream (and (input-stream-p stream) stream))))
 
-(defun mapc-open-input-streams (function &rest streams)
+(defun mapc-open-input-streams (function streams)
   (dolist (stream streams streams)
     (when-let ((input-stream (stream->input-stream stream)))
       (when (open-stream-p input-stream)
@@ -737,7 +729,7 @@ Does not currently establish a PAM session."
     (two-way-stream (two-way-stream-output-stream stream))
     (stream (and (output-stream-p stream) stream))))
 
-(defun mapc-open-output-streams (function &rest streams)
+(defun mapc-open-output-streams (function streams)
   (dolist (stream streams streams)
     (when-let ((output-stream (stream->output-stream stream)))
       (when (open-stream-p output-stream)
